# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.catalogs import template_pb2 as v1_dot_catalogs_dot_template__pb2


class ProductTemplateServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ProductTemplateCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateCreate",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateResponse.FromString,
        )
        self.ProductTemplateRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateRead",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateReadResponse.FromString,
        )
        self.ProductTemplateUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateUpdate",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateResponse.FromString,
        )
        self.ProductTemplateDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateDelete",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteResponse.FromString,
        )
        self.ProductCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductCreate",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductCreateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductCreateResponse.FromString,
        )
        self.ProductRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductRead",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductReadResponse.FromString,
        )
        self.ProductUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductUpdate",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductUpdateResponse.FromString,
        )
        self.ProductDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductDelete",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductDeleteResponse.FromString,
        )
        self.ProductAllRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductAllRead",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductAllReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductAllReadResponse.FromString,
        )


class ProductTemplateServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ProductTemplateCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductTemplateRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductTemplateUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductTemplateDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductAllRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ProductTemplateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ProductTemplateCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductTemplateCreate,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateResponse.SerializeToString,
        ),
        "ProductTemplateRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProductTemplateRead,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateReadResponse.SerializeToString,
        ),
        "ProductTemplateUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductTemplateUpdate,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateResponse.SerializeToString,
        ),
        "ProductTemplateDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ProductTemplateDelete,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteResponse.SerializeToString,
        ),
        "ProductCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductCreate,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductCreateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductCreateResponse.SerializeToString,
        ),
        "ProductRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProductRead,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductReadResponse.SerializeToString,
        ),
        "ProductUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductUpdate,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductUpdateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductUpdateResponse.SerializeToString,
        ),
        "ProductDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ProductDelete,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductDeleteRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductDeleteResponse.SerializeToString,
        ),
        "ProductAllRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProductAllRead,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductAllReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductAllReadResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.catalogs.template.ProductTemplateService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ProductTemplateService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ProductTemplateCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateCreate",
            v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductTemplateRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateRead",
            v1_dot_catalogs_dot_template__pb2.ProductTemplateReadRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductTemplateReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductTemplateUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateUpdate",
            v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductTemplateDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateDelete",
            v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductCreate",
            v1_dot_catalogs_dot_template__pb2.ProductCreateRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductRead",
            v1_dot_catalogs_dot_template__pb2.ProductReadRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductUpdate",
            v1_dot_catalogs_dot_template__pb2.ProductUpdateRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductDelete",
            v1_dot_catalogs_dot_template__pb2.ProductDeleteRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductAllRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductAllRead",
            v1_dot_catalogs_dot_template__pb2.ProductAllReadRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductAllReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/catalogs/template.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.catalogs import family_pb2 as v1_dot_catalogs_dot_family__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1av1/catalogs/template.proto\x12%pro.omni.oms.api.v1.catalogs.template\x1a\x11\x63ommon/base.proto\x1a\x18v1/catalogs/family.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xd5\x01\n\x0fProductTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12;\n\x06\x66\x61mily\x18\x04 \x01(\x0b\x32+.pro.omni.oms.api.v1.catalogs.family.Family\x12\x31\n\x10\x61ttribute_values\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue"\xb8\x01\n\x1cProductTemplateCreateRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfamily_id\x18\x03 \x01(\t\x12\x31\n\x10\x61ttribute_values\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbc\x01\n\x1dProductTemplateCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\x10product_template\x18\x02 \x01(\x0b\x32\x36.pro.omni.oms.api.v1.catalogs.template.ProductTemplate"\xf8\x02\n\x1aProductTemplateReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf6\x01\n\x1bProductTemplateReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12Q\n\x11product_templates\x18\x02 \x03(\x0b\x32\x36.pro.omni.oms.api.v1.catalogs.template.ProductTemplate\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\xa8\x01\n\x1cProductTemplateUpdateRequest\x12P\n\x10product_template\x18\x01 \x01(\x0b\x32\x36.pro.omni.oms.api.v1.catalogs.template.ProductTemplate\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbc\x01\n\x1dProductTemplateUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\x10product_template\x18\x02 \x01(\x0b\x32\x36.pro.omni.oms.api.v1.catalogs.template.ProductTemplate"b\n\x1cProductTemplateDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"j\n\x1dProductTemplateDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xad\x01\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13product_template_id\x18\x04 \x01(\t\x12\x31\n\x10\x61ttribute_values\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue"\xba\x01\n\x14ProductCreateRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13product_template_id\x18\x03 \x01(\t\x12\x31\n\x10\x61ttribute_values\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15ProductCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07product\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.template.Product"\xf0\x02\n\x12ProductReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n\x13ProductReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12@\n\x08products\x18\x02 \x03(\x0b\x32..pro.omni.oms.api.v1.catalogs.template.Product\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\x8f\x01\n\x14ProductUpdateRequest\x12?\n\x07product\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.template.Product\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15ProductUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07product\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.template.Product"Z\n\x14ProductDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15ProductDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x84\x01\n\nProductAll\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0f\n\x07img_url\x18\x05 \x01(\t\x12\x1b\n\x13product_template_id\x18\x06 \x01(\t\x12\x12\n\nproduct_id\x18\x07 \x01(\t"\xe7\x02\n\x15ProductAllReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe6\x01\n\x16ProductAllReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x46\n\x0bproduct_all\x18\x02 \x03(\x0b\x32\x31.pro.omni.oms.api.v1.catalogs.template.ProductAll\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData2\xf6\n\n\x16ProductTemplateService\x12\xa4\x01\n\x15ProductTemplateCreate\x12\x43.pro.omni.oms.api.v1.catalogs.template.ProductTemplateCreateRequest\x1a\x44.pro.omni.oms.api.v1.catalogs.template.ProductTemplateCreateResponse"\x00\x12\x9e\x01\n\x13ProductTemplateRead\x12\x41.pro.omni.oms.api.v1.catalogs.template.ProductTemplateReadRequest\x1a\x42.pro.omni.oms.api.v1.catalogs.template.ProductTemplateReadResponse"\x00\x12\xa4\x01\n\x15ProductTemplateUpdate\x12\x43.pro.omni.oms.api.v1.catalogs.template.ProductTemplateUpdateRequest\x1a\x44.pro.omni.oms.api.v1.catalogs.template.ProductTemplateUpdateResponse"\x00\x12\xa4\x01\n\x15ProductTemplateDelete\x12\x43.pro.omni.oms.api.v1.catalogs.template.ProductTemplateDeleteRequest\x1a\x44.pro.omni.oms.api.v1.catalogs.template.ProductTemplateDeleteResponse"\x00\x12\x8c\x01\n\rProductCreate\x12;.pro.omni.oms.api.v1.catalogs.template.ProductCreateRequest\x1a<.pro.omni.oms.api.v1.catalogs.template.ProductCreateResponse"\x00\x12\x86\x01\n\x0bProductRead\x12\x39.pro.omni.oms.api.v1.catalogs.template.ProductReadRequest\x1a:.pro.omni.oms.api.v1.catalogs.template.ProductReadResponse"\x00\x12\x8c\x01\n\rProductUpdate\x12;.pro.omni.oms.api.v1.catalogs.template.ProductUpdateRequest\x1a<.pro.omni.oms.api.v1.catalogs.template.ProductUpdateResponse"\x00\x12\x8c\x01\n\rProductDelete\x12;.pro.omni.oms.api.v1.catalogs.template.ProductDeleteRequest\x1a<.pro.omni.oms.api.v1.catalogs.template.ProductDeleteResponse"\x00\x12\x8f\x01\n\x0eProductAllRead\x12<.pro.omni.oms.api.v1.catalogs.template.ProductAllReadRequest\x1a=.pro.omni.oms.api.v1.catalogs.template.ProductAllReadResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.catalogs.template_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PRODUCTTEMPLATE"]._serialized_start = 177
    _globals["_PRODUCTTEMPLATE"]._serialized_end = 390
    _globals["_PRODUCTTEMPLATECREATEREQUEST"]._serialized_start = 393
    _globals["_PRODUCTTEMPLATECREATEREQUEST"]._serialized_end = 577
    _globals["_PRODUCTTEMPLATECREATERESPONSE"]._serialized_start = 580
    _globals["_PRODUCTTEMPLATECREATERESPONSE"]._serialized_end = 768
    _globals["_PRODUCTTEMPLATEREADREQUEST"]._serialized_start = 771
    _globals["_PRODUCTTEMPLATEREADREQUEST"]._serialized_end = 1147
    _globals["_PRODUCTTEMPLATEREADRESPONSE"]._serialized_start = 1150
    _globals["_PRODUCTTEMPLATEREADRESPONSE"]._serialized_end = 1396
    _globals["_PRODUCTTEMPLATEUPDATEREQUEST"]._serialized_start = 1399
    _globals["_PRODUCTTEMPLATEUPDATEREQUEST"]._serialized_end = 1567
    _globals["_PRODUCTTEMPLATEUPDATERESPONSE"]._serialized_start = 1570
    _globals["_PRODUCTTEMPLATEUPDATERESPONSE"]._serialized_end = 1758
    _globals["_PRODUCTTEMPLATEDELETEREQUEST"]._serialized_start = 1760
    _globals["_PRODUCTTEMPLATEDELETEREQUEST"]._serialized_end = 1858
    _globals["_PRODUCTTEMPLATEDELETERESPONSE"]._serialized_start = 1860
    _globals["_PRODUCTTEMPLATEDELETERESPONSE"]._serialized_end = 1966
    _globals["_PRODUCT"]._serialized_start = 1969
    _globals["_PRODUCT"]._serialized_end = 2142
    _globals["_PRODUCTCREATEREQUEST"]._serialized_start = 2145
    _globals["_PRODUCTCREATEREQUEST"]._serialized_end = 2331
    _globals["_PRODUCTCREATERESPONSE"]._serialized_start = 2334
    _globals["_PRODUCTCREATERESPONSE"]._serialized_end = 2497
    _globals["_PRODUCTREADREQUEST"]._serialized_start = 2500
    _globals["_PRODUCTREADREQUEST"]._serialized_end = 2868
    _globals["_PRODUCTREADRESPONSE"]._serialized_start = 2871
    _globals["_PRODUCTREADRESPONSE"]._serialized_end = 3092
    _globals["_PRODUCTUPDATEREQUEST"]._serialized_start = 3095
    _globals["_PRODUCTUPDATEREQUEST"]._serialized_end = 3238
    _globals["_PRODUCTUPDATERESPONSE"]._serialized_start = 3241
    _globals["_PRODUCTUPDATERESPONSE"]._serialized_end = 3404
    _globals["_PRODUCTDELETEREQUEST"]._serialized_start = 3406
    _globals["_PRODUCTDELETEREQUEST"]._serialized_end = 3496
    _globals["_PRODUCTDELETERESPONSE"]._serialized_start = 3498
    _globals["_PRODUCTDELETERESPONSE"]._serialized_end = 3596
    _globals["_PRODUCTALL"]._serialized_start = 3599
    _globals["_PRODUCTALL"]._serialized_end = 3731
    _globals["_PRODUCTALLREADREQUEST"]._serialized_start = 3734
    _globals["_PRODUCTALLREADREQUEST"]._serialized_end = 4093
    _globals["_PRODUCTALLREADRESPONSE"]._serialized_start = 4096
    _globals["_PRODUCTALLREADRESPONSE"]._serialized_end = 4326
    _globals["_PRODUCTTEMPLATESERVICE"]._serialized_start = 4329
    _globals["_PRODUCTTEMPLATESERVICE"]._serialized_end = 5727
# @@protoc_insertion_point(module_scope)



from enum import Enum, unique


@unique
class MicroService(Enum):
    SAAS_MS_USER = "saas-ms-user"
    SAAS_MS_CATALOG = "saas-ms-catalog"
    SAAS_MS_UTILITIES = "saas-ms-utilities"
    SAAS_MS_STOCK = "saas-ms-stock"
    SAAS_MS_CLIENT = "saas-ms-client"
    SAAS_MS_SALE = "saas-ms-sale"
    SAAS_MS_RULE = "saas-ms-rule"


class MicroServiceDocument(object):
    pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/language.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bv1/utilities/language.proto\x12&pro.omni.oms.api.v1.utilities.language\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc8\x02\n\x08Language\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x10\n\x08\x63ode_iso\x18\x04 \x01(\t\x12\x11\n\tdirection\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x61te_format\x18\x06 \x01(\t\x12\x13\n\x0btime_format\x18\x07 \x01(\t\x12\x15\n\rdecimal_point\x18\x08 \x01(\t\x12\x1b\n\x13thousands_separator\x18\t \x01(\t\x12\x10\n\x08grouping\x18\n \x01(\t\x12\x12\n\nweek_start\x18\x0b \x01(\t\x12*\n\x06\x61\x63tive\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\r \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xbd\x02\n\x12LanguageAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x10\n\x08\x63ode_iso\x18\x03 \x01(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x61te_format\x18\x05 \x01(\t\x12\x13\n\x0btime_format\x18\x06 \x01(\t\x12\x15\n\rdecimal_point\x18\x07 \x01(\t\x12\x1b\n\x13thousands_separator\x18\x08 \x01(\t\x12\x10\n\x08grouping\x18\t \x01(\t\x12\x12\n\nweek_start\x18\n \x01(\t\x12*\n\x06\x61\x63tive\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa4\x01\n\x13LanguageAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08language\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.language.Language"\xf1\x02\n\x13LanguageReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe1\x01\n\x14LanguageReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x43\n\tlanguages\x18\x03 \x03(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.language.Language"\x93\x01\n\x15LanguageUpdateRequest\x12\x42\n\x08language\x18\x01 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.language.Language\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x16LanguageUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08language\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.language.Language"[\n\x15LanguageDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16LanguageDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd2\x04\n\x0fLanguageService\x12\x88\x01\n\x0bLanguageAdd\x12:.pro.omni.oms.api.v1.utilities.language.LanguageAddRequest\x1a;.pro.omni.oms.api.v1.utilities.language.LanguageAddResponse"\x00\x12\x8b\x01\n\x0cLanguageRead\x12;.pro.omni.oms.api.v1.utilities.language.LanguageReadRequest\x1a<.pro.omni.oms.api.v1.utilities.language.LanguageReadResponse"\x00\x12\x91\x01\n\x0eLanguageUpdate\x12=.pro.omni.oms.api.v1.utilities.language.LanguageUpdateRequest\x1a>.pro.omni.oms.api.v1.utilities.language.LanguageUpdateResponse"\x00\x12\x91\x01\n\x0eLanguageDelete\x12=.pro.omni.oms.api.v1.utilities.language.LanguageDeleteRequest\x1a>.pro.omni.oms.api.v1.utilities.language.LanguageDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.language_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_LANGUAGE"]._serialized_start = 123
    _globals["_LANGUAGE"]._serialized_end = 451
    _globals["_LANGUAGEADDREQUEST"]._serialized_start = 454
    _globals["_LANGUAGEADDREQUEST"]._serialized_end = 771
    _globals["_LANGUAGEADDRESPONSE"]._serialized_start = 774
    _globals["_LANGUAGEADDRESPONSE"]._serialized_end = 938
    _globals["_LANGUAGEREADREQUEST"]._serialized_start = 941
    _globals["_LANGUAGEREADREQUEST"]._serialized_end = 1310
    _globals["_LANGUAGEREADRESPONSE"]._serialized_start = 1313
    _globals["_LANGUAGEREADRESPONSE"]._serialized_end = 1538
    _globals["_LANGUAGEUPDATEREQUEST"]._serialized_start = 1541
    _globals["_LANGUAGEUPDATEREQUEST"]._serialized_end = 1688
    _globals["_LANGUAGEUPDATERESPONSE"]._serialized_start = 1691
    _globals["_LANGUAGEUPDATERESPONSE"]._serialized_end = 1858
    _globals["_LANGUAGEDELETEREQUEST"]._serialized_start = 1860
    _globals["_LANGUAGEDELETEREQUEST"]._serialized_end = 1951
    _globals["_LANGUAGEDELETERESPONSE"]._serialized_start = 1953
    _globals["_LANGUAGEDELETERESPONSE"]._serialized_end = 2052
    _globals["_LANGUAGESERVICE"]._serialized_start = 2055
    _globals["_LANGUAGESERVICE"]._serialized_end = 2649
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/payment_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!v1/utilities/payment_method.proto\x12,pro.omni.oms.api.v1.utilities.payment_method\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb9\x01\n\rPaymentMethod\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x92\x01\n\x17PaymentMethodAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xba\x01\n\x18PaymentMethodAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12S\n\x0epayment_method\x18\x02 \x01(\x0b\x32;.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethod"\xf6\x02\n\x18PaymentMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf7\x01\n\x19PaymentMethodReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12T\n\x0fpayment_methods\x18\x03 \x03(\x0b\x32;.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethod"\xa9\x01\n\x1aPaymentMethodUpdateRequest\x12S\n\x0epayment_method\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1bPaymentMethodUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12S\n\x0epayment_method\x18\x02 \x01(\x0b\x32;.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethod"`\n\x1aPaymentMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"h\n\x1bPaymentMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xc3\x05\n\x14PaymentMethodService\x12\xa3\x01\n\x10PaymentMethodAdd\x12\x45.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodAddRequest\x1a\x46.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodAddResponse"\x00\x12\xa6\x01\n\x11PaymentMethodRead\x12\x46.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodReadRequest\x1aG.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodReadResponse"\x00\x12\xac\x01\n\x13PaymentMethodUpdate\x12H.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodUpdateRequest\x1aI.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodUpdateResponse"\x00\x12\xac\x01\n\x13PaymentMethodDelete\x12H.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodDeleteRequest\x1aI.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.payment_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PAYMENTMETHOD"]._serialized_start = 135
    _globals["_PAYMENTMETHOD"]._serialized_end = 320
    _globals["_PAYMENTMETHODADDREQUEST"]._serialized_start = 323
    _globals["_PAYMENTMETHODADDREQUEST"]._serialized_end = 469
    _globals["_PAYMENTMETHODADDRESPONSE"]._serialized_start = 472
    _globals["_PAYMENTMETHODADDRESPONSE"]._serialized_end = 658
    _globals["_PAYMENTMETHODREADREQUEST"]._serialized_start = 661
    _globals["_PAYMENTMETHODREADREQUEST"]._serialized_end = 1035
    _globals["_PAYMENTMETHODREADRESPONSE"]._serialized_start = 1038
    _globals["_PAYMENTMETHODREADRESPONSE"]._serialized_end = 1285
    _globals["_PAYMENTMETHODUPDATEREQUEST"]._serialized_start = 1288
    _globals["_PAYMENTMETHODUPDATEREQUEST"]._serialized_end = 1457
    _globals["_PAYMENTMETHODUPDATERESPONSE"]._serialized_start = 1460
    _globals["_PAYMENTMETHODUPDATERESPONSE"]._serialized_end = 1649
    _globals["_PAYMENTMETHODDELETEREQUEST"]._serialized_start = 1651
    _globals["_PAYMENTMETHODDELETEREQUEST"]._serialized_end = 1747
    _globals["_PAYMENTMETHODDELETERESPONSE"]._serialized_start = 1749
    _globals["_PAYMENTMETHODDELETERESPONSE"]._serialized_end = 1853
    _globals["_PAYMENTMETHODSERVICE"]._serialized_start = 1856
    _globals["_PAYMENTMETHODSERVICE"]._serialized_end = 2563
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import flow_pb2 as v1_dot_sales_dot_flow__pb2


class FlowServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FlowCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.flow.FlowService/FlowCreate",
            request_serializer=v1_dot_sales_dot_flow__pb2.FlowCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_flow__pb2.FlowCreateResponse.FromString,
        )
        self.FlowRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.flow.FlowService/FlowRead",
            request_serializer=v1_dot_sales_dot_flow__pb2.FlowReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_flow__pb2.FlowReadResponse.FromString,
        )
        self.FlowUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.flow.FlowService/FlowUpdate",
            request_serializer=v1_dot_sales_dot_flow__pb2.FlowUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_flow__pb2.FlowUpdateResponse.FromString,
        )
        self.FlowDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.flow.FlowService/FlowDelete",
            request_serializer=v1_dot_sales_dot_flow__pb2.FlowDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_flow__pb2.FlowDeleteResponse.FromString,
        )


class FlowServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FlowCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FlowRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FlowUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FlowDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_FlowServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "FlowCreate": grpc.unary_unary_rpc_method_handler(
            servicer.FlowCreate,
            request_deserializer=v1_dot_sales_dot_flow__pb2.FlowCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_flow__pb2.FlowCreateResponse.SerializeToString,
        ),
        "FlowRead": grpc.unary_unary_rpc_method_handler(
            servicer.FlowRead,
            request_deserializer=v1_dot_sales_dot_flow__pb2.FlowReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_flow__pb2.FlowReadResponse.SerializeToString,
        ),
        "FlowUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.FlowUpdate,
            request_deserializer=v1_dot_sales_dot_flow__pb2.FlowUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_flow__pb2.FlowUpdateResponse.SerializeToString,
        ),
        "FlowDelete": grpc.unary_unary_rpc_method_handler(
            servicer.FlowDelete,
            request_deserializer=v1_dot_sales_dot_flow__pb2.FlowDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_flow__pb2.FlowDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.flow.FlowService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class FlowService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FlowCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.flow.FlowService/FlowCreate",
            v1_dot_sales_dot_flow__pb2.FlowCreateRequest.SerializeToString,
            v1_dot_sales_dot_flow__pb2.FlowCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FlowRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.flow.FlowService/FlowRead",
            v1_dot_sales_dot_flow__pb2.FlowReadRequest.SerializeToString,
            v1_dot_sales_dot_flow__pb2.FlowReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FlowUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.flow.FlowService/FlowUpdate",
            v1_dot_sales_dot_flow__pb2.FlowUpdateRequest.SerializeToString,
            v1_dot_sales_dot_flow__pb2.FlowUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def FlowDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.flow.FlowService/FlowDelete",
            v1_dot_sales_dot_flow__pb2.FlowDeleteRequest.SerializeToString,
            v1_dot_sales_dot_flow__pb2.FlowDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from typing import Optional as _Optional

from omni.pro.database import DBUtil
from omni.pro.logger import LoggerTraceback, configure_logger
from omni.pro.protos.common import base_pb2
from omni.pro.stack import ExitStackDocument
from omni.pro.util import HTTPStatus

logger = configure_logger(name=__name__)


class MessageCode(object):
    INTERNAL_SERVER_ERROR = "SV001"
    INPUT_VALIDATOR_ERROR = "SV002"
    COGNITO_CLIENT_ERROR = "CO001"
    USER_PASSWORD_CHANGED = "US007"
    USER_EMAIL_CHANGED = "US008"
    USER_UNAUTHORIZED = "US009"
    RESOURCE_CREATED = "RS001"
    RESOURCE_READ = "RS002"
    RESOURCE_FETCHED = "RS002"
    RESOURCE_UPDATED = "RS003"
    RESOURCE_DELETED = "RS004"
    RESOURCE_NOT_FOUND = "RS005"
    RESOURCE_ALREADY_EXISTS = "RS006"


class MessageResponse(object):
    def __init__(self, cls):
        self.cls = cls

    def response(
        self,
        message: str,
        success: bool,
        status_code: int = HTTPStatus.OK,
        message_code: _Optional[str] = ...,
        **kwargs,
    ):
        return self.cls(
            response_standard=base_pb2.ResponseStandard(
                success=success, message=message, status_code=status_code, message_code=message_code
            ),
            **kwargs,
        )

    # FIXME: This is a bad name for this method
    def bad_response(self, message: str, **kwargs):
        return self.input_validator_response(message, **kwargs)

    def input_validator_response(self, message: str, **kwargs):
        return self.response(
            success=False,
            message=message,
            status_code=HTTPStatus.BAD_REQUEST,
            message_code=MessageCode.INPUT_VALIDATOR_ERROR,
            **kwargs,
        )

    def created_response(self, message: str, **kwargs):
        return self.response(
            success=True,
            message=message,
            status_code=HTTPStatus.CREATED,
            message_code=MessageCode.RESOURCE_CREATED,
            **kwargs,
        )

    def deleted_response(self, message: str, **kwargs):
        return self.response(
            success=True,
            message=message,
            status_code=HTTPStatus.OK,
            message_code=MessageCode.RESOURCE_DELETED,
            **kwargs,
        )

    def updated_response(self, message: str, **kwargs):
        return self.response(
            success=True,
            message=message,
            status_code=HTTPStatus.OK,
            message_code=MessageCode.RESOURCE_UPDATED,
            **kwargs,
        )

    def fetched_response(
        self, message: str, paginated: base_pb2.Paginated, total: int, count=0, message_not_found="", **kwargs
    ):
        if kwargs.pop("id", False) and total == 0:
            return self.not_found_response(message_not_found, **kwargs)

        return self.response(
            success=total > 0,
            message=message,
            status_code=HTTPStatus.OK,
            message_code=MessageCode.RESOURCE_FETCHED,
            meta_data=base_pb2.MetaData(
                limit=paginated.limit,
                offset=paginated.offset,
                total=total,
                count=count or total,
            ),
            **kwargs,
        )

    def internal_response(self, message: str, message_code: str = MessageCode.INTERNAL_SERVER_ERROR, **kwargs):
        return self.response(
            message=message,
            success=False,
            status_code=HTTPStatus.INTERNAL_SERVER_ERROR,
            message_code=message_code,
            **kwargs,
        )

    def already_exists_response(self, message: str, **kwargs):
        return self.response(
            success=False,
            message=message,
            status_code=HTTPStatus.OK,
            message_code=MessageCode.RESOURCE_ALREADY_EXISTS,
            **kwargs,
        )

    def not_found_response(self, message: str, **kwargs):
        return self.response(
            success=False,
            message=message,
            status_code=HTTPStatus.NOT_FOUND,
            message_code=MessageCode.RESOURCE_NOT_FOUND,
            **kwargs,
        )

    def unauthorized_response(self, message: str = "User Unauthorized", **kwargs):
        return self.response(
            success=False,
            message=message,
            status_code=HTTPStatus.UNAUTHORIZED,
            message_code=MessageCode.USER_UNAUTHORIZED,
            **kwargs,
        )

    def method_not_allowed_response(self, message: str = "Method Not Allowed", **kwargs):
        return self.response(
            success=False,
            message=message,
            status_code=HTTPStatus.METHOD_NOT_ALLOWED,
            message_code=MessageCode.USER_UNAUTHORIZED,
            **kwargs,
        )


def read_response(
    request,
    context,
    document_class,
    reference_list: list,
    message_response: MessageResponse,
    msg_success: str,
    msg_exception: str,
    entry_field_name: str,
    **kwargs,
):
    """
    :param request: request is a Message grpc\n
    :param context: context is a Message grpc with db_manager, db_name field\n
    :param document_class: document_class is a Document class\n
    :param reference_list: reference_list is a list of Document class\n
    :param message_response: message_response is a MessageResponse instance\n
    :param msg_success: msg_success is a success message\n
    :param msg_exception: msg_exception is a exception message\n
    :return: MessageResponse cls param
    """
    try:
        with ExitStackDocument(document_classes=reference_list, db_alias=context.db_name):
            data = DBUtil.db_prepared_statement(
                request.id,
                request.fields,
                request.filter,
                request.paginated,
                None,
                request.sort_by,
            )
            list_docs, total = context.db_manager.list_documents(
                context.db_name,
                request.context.tenant,
                document_class,
                **data,
            )
            kwargs_return = {
                f"{entry_field_name}": [doc.to_proto() for doc in list_docs],
            } | kwargs
            return message_response.fetched_response(
                message=msg_success,
                total=total,
                count=len(list_docs),
                id=request.id,
                paginated=request.paginated,
                **kwargs_return,
            )
    except ValueError as e:
        LoggerTraceback.error("Input request data validation error", e, logger)
        return message_response.input_validator_response(message=str(e))
    except Exception as e:
        LoggerTraceback.error(msg_exception, e, logger)
        return message_response.internal_response(message=msg_exception)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    delivery_price_delivery_method_pb2 as v1_dot_rules_dot_delivery__price__delivery__method__pb2,
)


class DeliveryPriceDeliveryMethodServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryPriceDeliveryMethodCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodService/DeliveryPriceDeliveryMethodCreate",
            request_serializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodCreateResponse.FromString,
        )
        self.DeliveryPriceDeliveryMethodRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodService/DeliveryPriceDeliveryMethodRead",
            request_serializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodReadResponse.FromString,
        )
        self.DeliveryPriceDeliveryMethodUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodService/DeliveryPriceDeliveryMethodUpdate",
            request_serializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodUpdateResponse.FromString,
        )
        self.DeliveryPriceDeliveryMethodDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodService/DeliveryPriceDeliveryMethodDelete",
            request_serializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodDeleteResponse.FromString,
        )


class DeliveryPriceDeliveryMethodServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryPriceDeliveryMethodCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceDeliveryMethodRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceDeliveryMethodUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryPriceDeliveryMethodDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryPriceDeliveryMethodServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryPriceDeliveryMethodCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceDeliveryMethodCreate,
            request_deserializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodCreateResponse.SerializeToString,
        ),
        "DeliveryPriceDeliveryMethodRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceDeliveryMethodRead,
            request_deserializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodReadResponse.SerializeToString,
        ),
        "DeliveryPriceDeliveryMethodUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceDeliveryMethodUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodUpdateResponse.SerializeToString,
        ),
        "DeliveryPriceDeliveryMethodDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryPriceDeliveryMethodDelete,
            request_deserializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryPriceDeliveryMethodService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryPriceDeliveryMethodCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodService/DeliveryPriceDeliveryMethodCreate",
            v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceDeliveryMethodRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodService/DeliveryPriceDeliveryMethodRead",
            v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceDeliveryMethodUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodService/DeliveryPriceDeliveryMethodUpdate",
            v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryPriceDeliveryMethodDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_price_delivery_method.DeliveryPriceDeliveryMethodService/DeliveryPriceDeliveryMethodDelete",
            v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__price__delivery__method__pb2.DeliveryPriceDeliveryMethodDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_shipper.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import carrier_pb2 as v1_dot_rules_dot_carrier__pb2
from omni.pro.protos.v1.rules import delivery_locality_pb2 as v1_dot_rules_dot_delivery__locality__pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as v1_dot_rules_dot_delivery__method__pb2
from omni.pro.protos.v1.rules import schedule_work_pb2 as v1_dot_rules_dot_schedule__work__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fv1/rules/delivery_shipper.proto\x12*pro.omni.oms.api.v1.rules.delivery_shipper\x1a\x11\x63ommon/base.proto\x1a\x1ev1/rules/delivery_method.proto\x1a\x16v1/rules/carrier.proto\x1a\x18v1/rules/warehouse.proto\x1a\x1cv1/rules/schedule_work.proto\x1a v1/rules/delivery_locality.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x97\x05\n\x0f\x44\x65liveryShipper\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x44\n\x10\x64\x65livery_carrier\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.carrier.Carrier\x12S\n\x10\x64\x65livery_methods\x18\x05 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x16\n\x0emaximum_weight\x18\x06 \x01(\x02\x12\x16\n\x0emaximum_volume\x18\x07 \x01(\x02\x12N\n\x0fschedule_pickup\x18\x08 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12Y\n\x12locality_available\x18\t \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocality\x12\x35\n\x11internal_transfer\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\nwarehouses\x18\x0b \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12*\n\x06\x61\x63tive\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\r \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe5\x02\n\x1c\x44\x65liveryShipperCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x65livery_carrier_id\x18\x03 \x01(\x05\x12\x1b\n\x13\x64\x65livery_method_ids\x18\x04 \x01(\t\x12\x16\n\x0emaximum_weight\x18\x05 \x01(\x02\x12\x16\n\x0emaximum_volume\x18\x06 \x01(\x02\x12\x1a\n\x12schedule_pickup_id\x18\x07 \x01(\t\x12\x1d\n\x15locality_available_id\x18\x08 \x01(\t\x12\x35\n\x11internal_transfer\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x15\n\rwarehouse_ids\x18\n \x01(\t\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc1\x01\n\x1d\x44\x65liveryShipperCreateResponse\x12U\n\x10\x64\x65livery_shipper\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipper\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf8\x02\n\x1a\x44\x65liveryShipperReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfb\x01\n\x1b\x44\x65liveryShipperReadResponse\x12V\n\x11\x64\x65livery_shippers\x18\x01 \x03(\x0b\x32;.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipper\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xad\x01\n\x1c\x44\x65liveryShipperUpdateRequest\x12U\n\x10\x64\x65livery_shipper\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipper\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc1\x01\n\x1d\x44\x65liveryShipperUpdateResponse\x12U\n\x10\x64\x65livery_shipper\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipper\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"b\n\x1c\x44\x65liveryShipperDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"j\n\x1d\x44\x65liveryShipperDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd6\x05\n\x16\x44\x65liveryShipperService\x12\xae\x01\n\x15\x44\x65liveryShipperCreate\x12H.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperCreateRequest\x1aI.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperCreateResponse"\x00\x12\xa8\x01\n\x13\x44\x65liveryShipperRead\x12\x46.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperReadRequest\x1aG.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperReadResponse"\x00\x12\xae\x01\n\x15\x44\x65liveryShipperUpdate\x12H.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperUpdateRequest\x1aI.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperUpdateResponse"\x00\x12\xae\x01\n\x15\x44\x65liveryShipperDelete\x12H.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperDeleteRequest\x1aI.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_shipper_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYSHIPPER"]._serialized_start = 277
    _globals["_DELIVERYSHIPPER"]._serialized_end = 940
    _globals["_DELIVERYSHIPPERCREATEREQUEST"]._serialized_start = 943
    _globals["_DELIVERYSHIPPERCREATEREQUEST"]._serialized_end = 1300
    _globals["_DELIVERYSHIPPERCREATERESPONSE"]._serialized_start = 1303
    _globals["_DELIVERYSHIPPERCREATERESPONSE"]._serialized_end = 1496
    _globals["_DELIVERYSHIPPERREADREQUEST"]._serialized_start = 1499
    _globals["_DELIVERYSHIPPERREADREQUEST"]._serialized_end = 1875
    _globals["_DELIVERYSHIPPERREADRESPONSE"]._serialized_start = 1878
    _globals["_DELIVERYSHIPPERREADRESPONSE"]._serialized_end = 2129
    _globals["_DELIVERYSHIPPERUPDATEREQUEST"]._serialized_start = 2132
    _globals["_DELIVERYSHIPPERUPDATEREQUEST"]._serialized_end = 2305
    _globals["_DELIVERYSHIPPERUPDATERESPONSE"]._serialized_start = 2308
    _globals["_DELIVERYSHIPPERUPDATERESPONSE"]._serialized_end = 2501
    _globals["_DELIVERYSHIPPERDELETEREQUEST"]._serialized_start = 2503
    _globals["_DELIVERYSHIPPERDELETEREQUEST"]._serialized_end = 2601
    _globals["_DELIVERYSHIPPERDELETERESPONSE"]._serialized_start = 2603
    _globals["_DELIVERYSHIPPERDELETERESPONSE"]._serialized_end = 2709
    _globals["_DELIVERYSHIPPERSERVICE"]._serialized_start = 2712
    _globals["_DELIVERYSHIPPERSERVICE"]._serialized_end = 3438
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/stock_batcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cv1/stock/stock_batcher.proto\x12+pro.omni.oms.api.v1.utilities.stock.batcher\x1a\x1cgoogle/protobuf/struct.proto\x1a\x11\x63ommon/base.proto"\xb6\x01\n\x13StockBatcherRequest\x12\x31\n\rstock_entries\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12&\n\x05\x62\x61tch\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"&\n\x14StockBatcherResponse\x12\x0e\n\x06record\x18\x01 \x01(\t2\xad\x01\n\x13StockBatcherService\x12\x95\x01\n\x0cStockBatcher\x12@.pro.omni.oms.api.v1.utilities.stock.batcher.StockBatcherRequest\x1a\x41.pro.omni.oms.api.v1.utilities.stock.batcher.StockBatcherResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.stock_batcher_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STOCKBATCHERREQUEST"]._serialized_start = 127
    _globals["_STOCKBATCHERREQUEST"]._serialized_end = 309
    _globals["_STOCKBATCHERRESPONSE"]._serialized_start = 311
    _globals["_STOCKBATCHERRESPONSE"]._serialized_end = 349
    _globals["_STOCKBATCHERSERVICE"]._serialized_start = 352
    _globals["_STOCKBATCHERSERVICE"]._serialized_end = 525
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import client_pb2 as v1_dot_sales_dot_client__pb2


class ClientServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ClientCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientCreate",
            request_serializer=v1_dot_sales_dot_client__pb2.ClientCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_client__pb2.ClientCreateResponse.FromString,
        )
        self.ClientRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientRead",
            request_serializer=v1_dot_sales_dot_client__pb2.ClientReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_client__pb2.ClientReadResponse.FromString,
        )
        self.ClientUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientUpdate",
            request_serializer=v1_dot_sales_dot_client__pb2.ClientUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_client__pb2.ClientUpdateResponse.FromString,
        )
        self.ClientDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientDelete",
            request_serializer=v1_dot_sales_dot_client__pb2.ClientDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_client__pb2.ClientDeleteResponse.FromString,
        )


class ClientServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ClientCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ClientRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ClientUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ClientDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ClientServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ClientCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ClientCreate,
            request_deserializer=v1_dot_sales_dot_client__pb2.ClientCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_client__pb2.ClientCreateResponse.SerializeToString,
        ),
        "ClientRead": grpc.unary_unary_rpc_method_handler(
            servicer.ClientRead,
            request_deserializer=v1_dot_sales_dot_client__pb2.ClientReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_client__pb2.ClientReadResponse.SerializeToString,
        ),
        "ClientUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ClientUpdate,
            request_deserializer=v1_dot_sales_dot_client__pb2.ClientUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_client__pb2.ClientUpdateResponse.SerializeToString,
        ),
        "ClientDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ClientDelete,
            request_deserializer=v1_dot_sales_dot_client__pb2.ClientDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_client__pb2.ClientDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.client.ClientService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ClientService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ClientCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientCreate",
            v1_dot_sales_dot_client__pb2.ClientCreateRequest.SerializeToString,
            v1_dot_sales_dot_client__pb2.ClientCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ClientRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientRead",
            v1_dot_sales_dot_client__pb2.ClientReadRequest.SerializeToString,
            v1_dot_sales_dot_client__pb2.ClientReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ClientUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientUpdate",
            v1_dot_sales_dot_client__pb2.ClientUpdateRequest.SerializeToString,
            v1_dot_sales_dot_client__pb2.ClientUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ClientDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientDelete",
            v1_dot_sales_dot_client__pb2.ClientDeleteRequest.SerializeToString,
            v1_dot_sales_dot_client__pb2.ClientDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.rules import location_pb2 as _location_pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as _warehouse_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class WarehouseHierarchy(_message.Message):
    __slots__ = [
        "id",
        "warehouse",
        "location",
        "quantity_security",
        "sequence",
        "sequence_order",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_SECURITY_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_ORDER_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    warehouse: _warehouse_pb2.Warehouse
    location: _location_pb2.Location
    quantity_security: float
    sequence: int
    sequence_order: _wrappers_pb2.BoolValue
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        warehouse: _Optional[_Union[_warehouse_pb2.Warehouse, _Mapping]] = ...,
        location: _Optional[_Union[_location_pb2.Location, _Mapping]] = ...,
        quantity_security: _Optional[float] = ...,
        sequence: _Optional[int] = ...,
        sequence_order: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class WarehouseHierarchyCreateRequest(_message.Message):
    __slots__ = ["warehouse_id", "location_id", "quantity_security", "sequence", "sequence_order", "context"]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_SECURITY_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_ORDER_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    warehouse_id: int
    location_id: int
    quantity_security: float
    sequence: int
    sequence_order: _wrappers_pb2.BoolValue
    context: _base_pb2.Context
    def __init__(
        self,
        warehouse_id: _Optional[int] = ...,
        location_id: _Optional[int] = ...,
        quantity_security: _Optional[float] = ...,
        sequence: _Optional[int] = ...,
        sequence_order: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WarehouseHierarchyCreateResponse(_message.Message):
    __slots__ = ["warehouse_hierarchy", "response_standard"]
    WAREHOUSE_HIERARCHY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    warehouse_hierarchy: WarehouseHierarchy
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        warehouse_hierarchy: _Optional[_Union[WarehouseHierarchy, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class WarehouseHierarchyReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WarehouseHierarchyReadResponse(_message.Message):
    __slots__ = ["warehouses_hierarchy", "meta_data", "response_standard"]
    WAREHOUSES_HIERARCHY_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    warehouses_hierarchy: _containers.RepeatedCompositeFieldContainer[WarehouseHierarchy]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        warehouses_hierarchy: _Optional[_Iterable[_Union[WarehouseHierarchy, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class WarehouseHierarchyUpdateRequest(_message.Message):
    __slots__ = ["warehouse_hierarchy", "context"]
    WAREHOUSE_HIERARCHY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    warehouse_hierarchy: WarehouseHierarchy
    context: _base_pb2.Context
    def __init__(
        self,
        warehouse_hierarchy: _Optional[_Union[WarehouseHierarchy, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class WarehouseHierarchyUpdateResponse(_message.Message):
    __slots__ = ["warehouse_hierarchy", "response_standard"]
    WAREHOUSE_HIERARCHY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    warehouse_hierarchy: WarehouseHierarchy
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        warehouse_hierarchy: _Optional[_Union[WarehouseHierarchy, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class WarehouseHierarchyDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class WarehouseHierarchyDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import country_pb2 as v1_dot_rules_dot_country__pb2


class CountryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CountryCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.country.CountryService/CountryCreate",
            request_serializer=v1_dot_rules_dot_country__pb2.CountryCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_country__pb2.CountryCreateResponse.FromString,
        )
        self.CountryRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.country.CountryService/CountryRead",
            request_serializer=v1_dot_rules_dot_country__pb2.CountryReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_country__pb2.CountryReadResponse.FromString,
        )
        self.CountryUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.country.CountryService/CountryUpdate",
            request_serializer=v1_dot_rules_dot_country__pb2.CountryUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_country__pb2.CountryUpdateResponse.FromString,
        )
        self.CountryDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.country.CountryService/CountryDelete",
            request_serializer=v1_dot_rules_dot_country__pb2.CountryDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_country__pb2.CountryDeleteResponse.FromString,
        )


class CountryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CountryCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CountryRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CountryUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CountryDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CountryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CountryCreate": grpc.unary_unary_rpc_method_handler(
            servicer.CountryCreate,
            request_deserializer=v1_dot_rules_dot_country__pb2.CountryCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_country__pb2.CountryCreateResponse.SerializeToString,
        ),
        "CountryRead": grpc.unary_unary_rpc_method_handler(
            servicer.CountryRead,
            request_deserializer=v1_dot_rules_dot_country__pb2.CountryReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_country__pb2.CountryReadResponse.SerializeToString,
        ),
        "CountryUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.CountryUpdate,
            request_deserializer=v1_dot_rules_dot_country__pb2.CountryUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_country__pb2.CountryUpdateResponse.SerializeToString,
        ),
        "CountryDelete": grpc.unary_unary_rpc_method_handler(
            servicer.CountryDelete,
            request_deserializer=v1_dot_rules_dot_country__pb2.CountryDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_country__pb2.CountryDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.country.CountryService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class CountryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CountryCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.country.CountryService/CountryCreate",
            v1_dot_rules_dot_country__pb2.CountryCreateRequest.SerializeToString,
            v1_dot_rules_dot_country__pb2.CountryCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CountryRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.country.CountryService/CountryRead",
            v1_dot_rules_dot_country__pb2.CountryReadRequest.SerializeToString,
            v1_dot_rules_dot_country__pb2.CountryReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CountryUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.country.CountryService/CountryUpdate",
            v1_dot_rules_dot_country__pb2.CountryUpdateRequest.SerializeToString,
            v1_dot_rules_dot_country__pb2.CountryUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CountryDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.country.CountryService/CountryDelete",
            v1_dot_rules_dot_country__pb2.CountryDeleteRequest.SerializeToString,
            v1_dot_rules_dot_country__pb2.CountryDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/tax.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/utilities/tax.proto\x12!pro.omni.oms.api.v1.utilities.tax\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xe4\x01\n\x03Tax\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04rate\x18\x04 \x01(\x02\x12\x10\n\x08rounding\x18\x05 \x01(\x01\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x06 \x01(\x05\x12\x10\n\x08position\x18\x07 \x01(\t\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xad\x01\n\rTaxAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04rate\x18\x03 \x01(\x02\x12\x10\n\x08rounding\x18\x04 \x01(\x01\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x05 \x01(\x05\x12\x10\n\x08position\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x90\x01\n\x0eTaxAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x03tax\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.tax.Tax"\xec\x02\n\x0eTaxReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xce\x01\n\x0fTaxReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x35\n\x05taxes\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.utilities.tax.Tax"\x7f\n\x10TaxUpdateRequest\x12\x33\n\x03tax\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.tax.Tax\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x11TaxUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x03tax\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.tax.Tax"V\n\x10TaxDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"^\n\x11TaxDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe5\x03\n\nTaxService\x12o\n\x06TaxAdd\x12\x30.pro.omni.oms.api.v1.utilities.tax.TaxAddRequest\x1a\x31.pro.omni.oms.api.v1.utilities.tax.TaxAddResponse"\x00\x12r\n\x07TaxRead\x12\x31.pro.omni.oms.api.v1.utilities.tax.TaxReadRequest\x1a\x32.pro.omni.oms.api.v1.utilities.tax.TaxReadResponse"\x00\x12x\n\tTaxUpdate\x12\x33.pro.omni.oms.api.v1.utilities.tax.TaxUpdateRequest\x1a\x34.pro.omni.oms.api.v1.utilities.tax.TaxUpdateResponse"\x00\x12x\n\tTaxDelete\x12\x33.pro.omni.oms.api.v1.utilities.tax.TaxDeleteRequest\x1a\x34.pro.omni.oms.api.v1.utilities.tax.TaxDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.tax_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TAX"]._serialized_start = 113
    _globals["_TAX"]._serialized_end = 341
    _globals["_TAXADDREQUEST"]._serialized_start = 344
    _globals["_TAXADDREQUEST"]._serialized_end = 517
    _globals["_TAXADDRESPONSE"]._serialized_start = 520
    _globals["_TAXADDRESPONSE"]._serialized_end = 664
    _globals["_TAXREADREQUEST"]._serialized_start = 667
    _globals["_TAXREADREQUEST"]._serialized_end = 1031
    _globals["_TAXREADRESPONSE"]._serialized_start = 1034
    _globals["_TAXREADRESPONSE"]._serialized_end = 1240
    _globals["_TAXUPDATEREQUEST"]._serialized_start = 1242
    _globals["_TAXUPDATEREQUEST"]._serialized_end = 1369
    _globals["_TAXUPDATERESPONSE"]._serialized_start = 1372
    _globals["_TAXUPDATERESPONSE"]._serialized_end = 1519
    _globals["_TAXDELETEREQUEST"]._serialized_start = 1521
    _globals["_TAXDELETEREQUEST"]._serialized_end = 1607
    _globals["_TAXDELETERESPONSE"]._serialized_start = 1609
    _globals["_TAXDELETERESPONSE"]._serialized_end = 1703
    _globals["_TAXSERVICE"]._serialized_start = 1706
    _globals["_TAXSERVICE"]._serialized_end = 2191
# @@protoc_insertion_point(module_scope)
